# Summary

[Introduction](./index.md)

---

# Getting Started

- [Installation](./getting-started/installation.md)
- [Quick Start](./getting-started/quick-start.md)
- [Basic Concepts](./getting-started/concepts.md)

---

# Using Akira

- [Interactive Console](./using-akira/console.md)
- [Targets](./using-akira/targets.md)
  - [Generic API](./using-akira/targets/api.md)
  - [OpenAI](./using-akira/targets/openai.md)
  - [Anthropic](./using-akira/targets/anthropic.md)
  - [HuggingFace](./using-akira/targets/huggingface.md)
  - [AWS Bedrock & SageMaker](./using-akira/targets/aws.md)
- [Running Attacks](./using-akira/running-attacks.md)
- [Target Profiles](./using-akira/profiles.md)
- [Search & Discovery](./using-akira/search.md)

---

# Attack Modules

- [Module Overview](./modules/overview.md)
- [Prompt Injection](./modules/injection.md)
- [Jailbreaks](./modules/jailbreak.md)
- [Data Extraction](./modules/extraction.md)
- [Denial of Service](./modules/dos.md)

---

# Development

- [Architecture](./development/architecture.md)
- [Writing Modules](./development/writing-modules.md)
- [Writing Targets](./development/writing-targets.md)
- [Rust Extensions](./development/rust.md)
- [Contributing](./development/contributing.md)

---

# Reference

- [CLI Reference](./reference/cli.md)
- [Console Commands](./reference/commands.md)
- [Configuration](./reference/configuration.md)
- [Storage & Database](./reference/storage.md)

---

[Changelog](./changelog.md)
